Run quality control checks
# S3 method for EZbakRFractions
EZQC(obj, features = NULL, populations = NULL, fraction_design = NULL, ...)A list of ggplot2 objects visualizing the various aspects of your data
assessed by EZQC().
EZbakRFractions object, which is an EZbakRData object on which
EstimateFractions has been run.
Set of features analyzed in the fractions table you are
interested QCing. This gets passed to EZget() to help find this table.
Set of mutation types analyzed in the fractions table
you are interested in QCing. This gets passed to EZget() to help find this table.
The fraction "design matrix" specified to get the
fractions table you are interested in QCing. This gets passed to EZget() to
help find this table.
Additional arguments. Currently goes unused.