EZbakRArrowData object constructor for internal usenew_EZbakRArrowData efficiently creates an object of class EZbakRArrowData.
It does not perform any rigorous checks of the legitimacy of this object.
new_EZbakRArrowData(cBds, metadf)Arrow dataset tracking the sample ID, mutational and nucleotide content, and feature assignment of sequencing reads.
Data frame tracking features of each of the samples included
in cBds.