EZbakRDataobject constructor for internal usenew_EZbakRData efficiently creates an object of class EZbakRData.
It does not perform any rigorous checks of the legitimacy of this object.
new_EZbakRData(cB, metadf)Data frame tracking the sample ID, mutational and nucleotide content, and feature assignment of sequencing reads.
Data frame tracking features of each of the samples included
in cB.