Learn R Programming

EZbakR (version 0.1.0)

standard_fraction_design: Standard fraction_design table for EstimateFractions

Description

An example fraction_design table for a standard NR-seq experiment with s^4U labeling. This table tells EstimateFractions that there are two populations of reads, one with high T-to-C mutation content and one with low T-to-C mutation content

Usage

standard_fraction_design

Arguments

Format

standard_fraction_design

A tibble with 2 rows and 2 columns:

TC

Boolean denoting if population represented by that row has high T-to-C mutational content

present

Boolean denoting if population represented by that row is expected to be present in this dataset