fraction_design table for EstimateFractionsAn example fraction_design table for a standard NR-seq experiment with
s^4U labeling. This table tells EstimateFractions that there are two
populations of reads, one with high T-to-C mutation content and one
with low T-to-C mutation content
standard_fraction_designstandard_fraction_design
A tibble with 2 rows and 2 columns:
Boolean denoting if population represented by that row has high T-to-C mutational content
Boolean denoting if population represented by that row is expected to be present in this dataset